#
# spec file for package google-compute-engine
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define setup_version 2.7.5

Name:           google-compute-engine
Version:        20180129
Release:        lp150.1.3
Summary:        GCE Instance Initialization
License:        Apache-2.0
Group:          System/Daemons
Url:            https://github.com/GoogleCloudPlatform/compute-image-packages
Source0:        compute-image-packages-%{version}.tar.gz
Source1:        google-accounts-daemon.suse
Source2:        google-clock-skew-daemon.suse
Source3:        google-instance-setup.suse
Source4:        google-ip-forwarding-daemon.suse
Source5:        google-shutdown-scripts.suse
Source6:        google-startup-scripts.suse
Source7:        google-compute-engine-rpmlintrc
Source8:        baselibs.conf
Patch1:         gcei-hide-py-deps.patch
Patch2:         gcei-scripts-after-reg.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Google Compute Engine instance code.

%package init
Summary:        GCE Instance Initialization
Group:          System/Daemons
Requires:       google-compute-engine-oslogin == %{version}
%if 0%{?suse_version} && 0%{?suse_version} > 1315
Requires:       python3-setuptools
%else
Requires:       python-setuptools
%endif
%if 0%{?suse_version} > 1140
Recommends:     google-cloud-sdk
Requires:       systemd
%endif
%{?systemd_requires}
%if 0%{?suse_version} < 1140
Requires:       insserv
Requires:       sysvinit
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1315
BuildRequires:  python3-setuptools
%else
BuildRequires:  python-setuptools
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1315
# These packages were not released in SLE 15 and later, thus no conflict needed
Conflicts:      google-startup-scripts
Conflicts:      google-daemon
Conflicts:      gcimagebundle
%endif

%description init
Initialization code for Google Compute Engine instances.

%package oslogin
Summary:        OS Login Functionality for Google Compute Engine
Group:          Hardware

Requires:       pam
Requires(post): openssh
Requires(post): glibc
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  libjson-c-devel
BuildRequires:  make
BuildRequires:  pam-devel

%description oslogin
Libraries and scripts  to enable OS Login functionality for
Google Compute Engine. Modifies sshd, nsswitch, and sshd_pam configurations.


%prep
%setup -q -n compute-image-packages-%{version}
%patch1
%patch2
find -name "*.py" | xargs sed -i 'sm#!/usr/bin/pythonmm'

%build
%if 0%{?suse_version} && 0%{?suse_version} > 1315
python3 setup.py build
%else
python setup.py build
%endif
pushd google_compute_engine_oslogin
make %{?_smp_mflags} LIBS="-lcurl -ljson-c"
popd

%install
%if 0%{?suse_version} && 0%{?suse_version} > 1315
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%else
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%endif
mkdir -p %{buildroot}%{_sbindir}
# Init
%if 0%{?suse_version} > 1140
mkdir -p %{buildroot}%{_unitdir}
cp google_compute_engine_init/systemd/*.service %{buildroot}%{_unitdir}
for srv_name in %{buildroot}%{_unitdir}/*.service; do rc_name=$(basename -s '.service' $srv_name); ln -s service %{buildroot}%{_sbindir}/rc$rc_name; done
%else
mkdir -p %{buildroot}%{_initddir}
cp %{SOURCE1} %{buildroot}%{_initddir}/google-accounts-daemon
cp %{SOURCE2} %{buildroot}%{_initddir}/google-clock-skew-daemon
cp %{SOURCE3} %{buildroot}%{_initddir}/google-instance-setup
cp %{SOURCE4} %{buildroot}%{_initddir}/google-ip-forwarding-daemon
cp %{SOURCE5} %{buildroot}%{_initddir}/google-shutdown-scripts
cp %{SOURCE6} %{buildroot}%{_initddir}/google-startup-scripts
for srv_name in %{buildroot}%{_initddir}/*; do rc_name=$(basename $srv_name); ln -s %{_initddir}/$rc_name %{buildroot}%{_sbindir}/rc$rc_name; done
%endif
# Sysconfig
mkdir -p %{buildroot}%{_sysconfdir}/sysctl.d
cp google_config/sysctl/11-gce-network-security.conf %{buildroot}%{_sysconfdir}/sysctl.d
# udev
%if 0%{?suse_version} < 1230
mkdir -p %{buildroot}/lib/udev/rules.d
cp google_config/udev/* %{buildroot}/lib/udev/rules.d
%else
mkdir -p %{buildroot}/usr/lib/udev/rules.d
cp google_config/udev/* %{buildroot}/usr/lib/udev/rules.d
%endif
# syslog
mkdir %{buildroot}/%{_sysconfdir}/rsyslog.d
cp google_config/rsyslog/* %{buildroot}/%{_sysconfdir}/rsyslog.d
# oslogin
pushd google_compute_engine_oslogin
make install DESTDIR=%{buildroot} NSS_INSTALL_PATH=%{_lib} PAM_INSTALL_PATH=%{_lib}/security
popd

%pre
%if 0%{?suse_version} > 1140
    %service_add_pre google-accounts-daemon.service google-clock-skew-daemon.service google-instance-setup.service google-ip-forwarding-daemon.service google-shutdown-scripts.service google-startup-scripts.service
%endif

%post
%if 0%{?suse_version} > 1140
    %service_add_post google-accounts-daemon.service google-clock-skew-daemon.service google-instance-setup.service google-ip-forwarding-daemon.service google-shutdown-scripts.service google-startup-scripts.service
%else
    %fillup_and_insserv -fy google-accounts-daemon
    %fillup_and_insserv -fy google-clock-skew-daemon
    %fillup_and_insserv -fy google-instance-setup
    %fillup_and_insserv -fy google-shutdown-scripts
    %fillup_and_insserv -fy google-startup-scripts
%endif

%post oslogin
/sbin/ldconfig

%preun
%if 0%{?suse_version} > 1140
    %service_del_preun google-accounts-daemon.service google-clock-skew-daemon.service google-instance-setup.service google-ip-forwarding-daemon.service google-shutdown-scripts.service google-startup-scripts.service
%else
    %stop_on_removal google-accounts-daemon
    %stop_on_removal google-clock-skew-daemon
    %stop_on_removal google-ip-forwarding-daemon
%endif

%postun
%restart_on_update
%if 0%{?suse_version} > 1140
    %service_del_postun google-accounts-daemon.service google-clock-skew-daemon.service google-instance-setup.service google-ip-forwarding-daemon.service google-shutdown-scripts.service google-startup-scripts.service
%else
    %insserv_cleanup
%endif

%postun oslogin
/sbin/ldconfig

%files init
%defattr(0644,root,root,0755)
%doc CONTRIB.md LICENSE README.md
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%dir %{python3_sitelib}/google_compute_engine
%dir %{python3_sitelib}/google_compute_engine-%{setup_version}-py%{py3_ver}.egg-info
%else
%dir %{python_sitelib}/google_compute_engine
%dir %{python_sitelib}/google_compute_engine-%{setup_version}-py%{py_ver}.egg-info
%endif
%exclude %{_bindir}/google_oslogin_control
%exclude %{_bindir}/google_authorized_keys
%attr(0755,root,root) %{_bindir}/*
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%{_sbindir}/*
%else
%attr(0755,root,root) %{_sbindir}/*
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%{python3_sitelib}/google_compute_engine/*
%else
%{python_sitelib}/google_compute_engine/*
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%{python3_sitelib}/google_compute_engine-%{setup_version}-py%{py3_ver}.egg-info/*
%else
%{python_sitelib}/google_compute_engine-%{setup_version}-py%{py_ver}.egg-info/*
%endif
%if 0%{?suse_version} > 1140
%{_unitdir}/*.service
%else
%attr(0755,root,root) %{_initddir}/*
%endif
%config %{_sysconfdir}/sysctl.d/*
%if 0%{?suse_version} < 1230
%dir %{_sysconfdir}/sysctl.d
%dir /lib/udev
%dir /lib/udev/rules.d
/lib/udev/rules.d/*
%else
%dir /usr/lib/udev
%dir /usr/lib/udev/rules.d
/usr/lib/udev/rules.d/*
%endif
%dir %{_sysconfdir}/rsyslog.d
%config %{_sysconfdir}/rsyslog.d/*

%files oslogin
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/google_oslogin_control
%attr(0755,root,root) %{_bindir}/google_authorized_keys
/%{_lib}/*
%if 0%{?suse_version} > 1140
%exclude /%{_lib}/udev*
%endif

%changelog
* Fri Feb  2 2018 adrian.glaubitz@suse.com
- Update to version 20180129 (bsc#1078349, bsc#1079077)
  + Improve rsyslog daemon reset when using the dhcp exit hook.
  + The OS Login feature is generally available.
  + Change the OS Login uid restriction to allow uid 1000.
  + Close socket connections after requesting metadata.
- From version 20171213
  + Force IPv4 for Debian apt configs.
* Sun Dec  3 2017 adrian.glaubitz@suse.com
- Update to version 20171129 (bsc#1070895, bsc#1070918)
  + Generate SSH host keys when none are present.
  + Improve logging when activating OS Login.
  + Fix parsing logic for expiration time on SSH public keys.
  + Fix home directory creation PAM config.
* Fri Nov  3 2017 rjschwei@suse.com
- Change dependencies -init depends on -oslogin
  + oslogin feature is now enabled by the initialization code
    when appropriate
- Do not start the oslogin feature upon package install
* Fri Oct 27 2017 rjschwei@suse.com
- Fix build for SLES 11
* Thu Oct 26 2017 adrian.glaubitz@suse.com
- Update to version 20171025 (bsc#1064356, bsc#1065308)
  + Add apt configuration to prevent auto-removal of Google packages.
  + Rename set_hostname to prevent naming conflicts.
  + Remove logging when checking OS Login status.
- From version 20171019
  + Support the enable-oslogin metadata key for activating OS Login.
  + Improve packaging to restart services.
  + OS Login is available in Beta.
  + Add status option to the OS Login control file.
- From version 20171006
  + Fix system hang during VM shutdown.
  + JSON parser accepts string types for int64 values.
- From version 20170921
  + JSON parser casts uid and gid to unsigned integers.
- From version 20170914
  + Remove fstab barrier options in EL 7.
  + Use curl to download metadata script files for SSL certificate validation.
  + Use netifaces for retrieving MAC address names if the import exists.
* Tue Sep 19 2017 rjschwei@suse.com
- Ship the udevrules with the -init package only
* Tue Sep 12 2017 rjschwei@suse.com
- Fix baslibs.conf, use package, not files
- Include rpmlintrc and baslibc.conf as source
* Mon Sep 11 2017 rjschwei@suse.com
- Add gcei-scripts-after-reg.patch (bsc#1057671)
* Sat Sep  9 2017 rjschwei@suse.com
- Update to version 20170829 (bsc#1049242, FATE#323757)
  + Support oslogin feature
  + Add rpmlintrc
    ~ We ship pam and nss modules in -oslogin we do not want
    to name the package according to the shared library naming policy
  + Add baslibs.config
    ~ Handle the nss and pam modules provided by oslogin properly
- From version 20170718
  + Allow nologin paths other than /sbin/nologin.
  + Try to download GCS URLs with curl if gsutil is not installed.
  + Fix control scripts to correctly restart sshd and nscd if they exist.
  + Retry HTTP requests if error 500 is received.
  + Move oslogin sudoers directory locations.
- Setup for Python 3 build oSTW and SLE 15
- Source package renamed to google-compute-engine
  + Binary subpackages -init -oslogin
* Fri Jan 13 2017 rjschwei@suse.com
- The startup script attempts a network connection, thus it must
  run after network setup
* Thu Jan 12 2017 rjschwei@suse.com
- Scripts that are one-shot should not be marked as "stop_on_removal"
  as there is no process running (bsc#1017395)
- One-shot scripts should not run with startproc
* Mon Dec 19 2016 rjschwei@suse.com
- Update to version 20161213 (bsc#1015829, bsc#1016372)
  + Remove gcei-handle-failed-open.patch included upstream
  + Remove gcei-handle-missing-gsutil.patch included upstream
  + Forward port gcei-hide-py-deps.patch
  + Improved alias IP support
- From 20161118
  + Add support for alias IPs in the IP forwarding daemon.
  + IP forwarding daemon adds back local routes after network restart.
  + Account daemon removes expired key access without metadata change.
  + Account daemon ignores SSH keys with non-ascii characters.
  + Improved exception handling.
  + Fix for syslog startup on systemd.
  + Add a route to the metadata server to /etc/hosts.
- From 20160930
  + Provide a service to enable network interfaces on boot.
  + Create a common library for inspecting network interfaces.
  + Allow metadata script output that is not UTF-8.
  + Fixed instance config file logic.
  + Fixed accounts management Python 3 compatibility.
  + Fixed IP forwarding Python 3 compatibility.
  + Improved style consistency.
  + Run a service on boot to enable additional network interfaces.
  + Update dhclient-script on EL 6 to fix local routing.
* Sun Oct 30 2016 jengelh@inai.de
- Resolve description inaccuracy
- Call %%service_* just once, but with all args
* Wed Oct 26 2016 rjschwei@suse.com
- Include in SLE 12 and SLE 11 (FATE#321748, FATE#321890, bsc#994943)
* Thu Oct 20 2016 rjschwei@suse.com
- Update gcei-handle-failed-open.patch to match upstream PR
* Wed Oct 19 2016 rjschwei@suse.com
- Add gcei-handle-failed-open.patch
  * Do not exit with a traceback if the sudoers file cannot be written
* Wed Oct 19 2016 rjschwei@suse.com
- Package the rsyslog config unconditionally, rsyslog also available on
  SLE 11
* Wed Oct 19 2016 rjschwei@suse.com
- Add sysvinit scripts for SUSE, upstream scripts are RHEL specific
  * google-accounts-daemon.suse
  * google-clock-skew-daemon.suse
  * google-instance-setup.suse
  * google-ip-forwarding-daemon.suse
  * google-shutdown-scripts.suse
  * google-startup-scripts.suse
* Mon Oct 17 2016 rjschwei@suse.com
- Own the udev directories, fixes issue with SLE 12 build
* Mon Oct 17 2016 rjschwei@suse.com
- Conflict with the previous generation of initialization code.
  * According to upstream and update path is not supported and
    has too many corner cases to reliably work. Thus running instances are
    not expected to upgrade.
* Mon Oct 17 2016 rjschwei@suse.com
- Initial build
  - Version 20160803
